#ifndef K3B_SOLARIS_DEVICE_H
#define K3B_SOLARIS_DEVICE_H

#ifdef __cplusplus
extern "C" {
#endif

#include <stdio.h>
#include <sys/types.h>
#include <sys/dkio.h>
#include <sys/stat.h>
#include <inttypes.h>
#include <kstat.h>
#include <sys/mkdev.h>
#include <sys/sysinfo.h>
#include <sys/utsname.h>
#include <devid.h>
#include <libdevinfo.h>
#include <dirent.h>

typedef struct DDIInfo
{
  int instance;
  char driver[8];
  char physicalPath[MAXPATHLEN];
} DDIInfo;

typedef struct DiskIOInfo
{
  kstat_io_t o;
  kstat_io_t n;
} DiskIOInfo;

typedef struct DiskSCSIInfo
{
    int instance;
    int kid;
    int lun;
    int target;
    dev_t dev;
    major_t major;
    minor_t minor;
    char kstatName[16];
    char kstatClass[64];
    char vendorName[32];
    char productId[64];
    char revision[32];
    char ddiDeviceName[MAXPATHLEN];
    char specType[16];
    char nodeType[64];
    char svr4Device[MAXPATHLEN];
    char scsiSlice[32];
    DiskIOInfo diskIOInfo;
} DiskSCSIInfo;

typedef struct UTSName
{
  int ok;
  struct utsname uName;
} UTSName;

extern DiskSCSIInfo* findDiskSCSIInfo (const char* ddiDeviceName);
extern DiskSCSIInfo* findSVR4Device (const char* deviceName);
extern DDIInfo* findDDIInfo (const char* ddiDeviceName);
extern DiskSCSIInfo* findSCSISlice (const char* sliceName);
extern int updateDeviceInfo (const char* driver);
extern int updateKStatList (void);


#ifdef __cplusplus
}
#endif

#endif

